@@ -1,24 +1,23 @@
 from __future__ import annotations
 from functools import cache
 
-from typing import Callable, Iterable, Union, Literal, Optional, Any
+from typing import Callable, Iterable, Union, Literal, Optional, cast
 from fastapi import Request, HTTPException, Query
 from starlette.datastructures import QueryParams
 from abc import ABC, abstractmethod
 from .operations import FiltrationOperator
-from .filtration import FiltrationData
+from .filtration import FiltrationData, ParsingData
 
 import inspect
-from functools import singledispatch
+
+
+WILDCARD_PARAMETER = "*"
 
 
 class QueryParsingException(HTTPException):
     """An exception that is raised when a filtration query if mallformed."""
 
 
-ParsingData = dict[str, Any]
-
-
 class QueryParser(ABC):
     """A base object to handle parsing the request query for filtration."""
 
@@ -29,7 +28,7 @@ class QueryParser(ABC):
         default_operator_factory: Callable[[str], FiltrationOperator],
         available_operators_factory: Callable[[str], list[FiltrationOperator]],
     ) -> None:
-        self._valid_columns = valid_columns
+        self._valid_columns = list(valid_columns)
         self._default_operator_factory = default_operator_factory
         self._available_operators_factory = available_operators_factory
 
@@ -52,12 +51,10 @@ class QueryParser(ABC):
                     f"{_filter!r} is a reserved keyword, can not use it for filtration"
                 )
 
-        result: ParsingData = {}
+        result = ParsingData()
         for key, value in query_params.multi_items():
             if self._verify_present(key):
-                result = QueryParser.__combine_parse_dicts(
-                    result, self._process_pair(key, value)
-                )
+                result += self._process_pair(key, value)
         return result
 
     @abstractmethod
@@ -72,16 +69,6 @@ class QueryParser(ABC):
     def modify_signature(self, func: Callable) -> Callable:
         """Modify a function signature to fix OpenAPI params."""
 
-    @staticmethod
-    def __combine_parse_dicts(first: ParsingData, other: ParsingData) -> ParsingData:
-        result = first.copy()
-        for k, v in other.items():
-            if k in result:
-                result[k].extend(v)
-            else:
-                result[k] = v
-        return ParsingData(result)
-
 
 class LHSQueryParser(QueryParser):
     """
@@ -139,20 +126,27 @@ class LHSQueryParser(QueryParser):
                     f"Available ones: {filtrations_possible_str}",
                 )
 
-            # Wildcard operator should work for each column
-            if key_data == "*":
-                return {
-                    "or": [{col: [(key_filter, value)]} for col in self._valid_columns]
-                }
-
-            return {key_data: [(key_filter, value)]}
-
         # Otherwise it will be considered an equality filter
         else:
-            return {key: [(self._default_operator_factory(key), value)]}
+            key_data = key
+            key_filter = self._default_operator_factory(key)
+
+        # Wildcard operator should work for each column
+        if key_data == WILDCARD_PARAMETER:
+            return ParsingData.disjunction(
+                [
+                    {"field": col, "op": key_filter, "value": value}
+                    for col in self._valid_columns
+                ]
+            )
+
+        return ParsingData.from_dict(
+            {"field": key_data, "op": key_filter, "value": value}
+        )
 
     def _verify_present(self, key: str) -> bool:
-        return key.split("[")[0] in self._valid_columns
+        col = key.split("[")[0]
+        return col in self._valid_columns + [WILDCARD_PARAMETER]
 
     def modify_signature(self, func: Callable) -> Callable:
         old_signature = inspect.signature(func)
@@ -197,7 +191,7 @@ class LHSQueryParser(QueryParser):
             annotation=Optional[str],
             default=Query(
                 None,
-                alias=f"*[<FilterOperator>]",
+                alias=f"{WILDCARD_PARAMETER}[<FilterOperator>]",
                 title=f"Filtering by all columns",
                 description="\n\n".join(
                     [
