@@ -24,6 +24,9 @@ class DataTable(GenericModel, Generic[_T]):
     def __len__(self) -> int:
         return len(self.items)
 
+    def __getitem__(self, num: int) -> _T:
+        return self.items[num]
+
     def convert(self, converter: Callable[[_T], _G]) -> DataTable[_G]:
         """
         Convert all items of current model to new model using a converter function.
